IMTreatment.vortex\_criterions.FTLE package
===========================================

.. automodule:: IMTreatment.vortex_criterions.FTLE
    :members:
    :undoc-members:
    :show-inheritance:

.. toctree::

   IMTreatment.vortex_criterions.FTLE.ftle

